==> kie-dmn-validation-999-20250203.023502-186-sources.jar: org/kie/dmn/validation/DMNv1x/Rules91573BCE7659DE46F3EF9933A8394CC6RuleMethods10.java <==
package org.kie.dmn.validation.DMNv1x;

import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;
import org.kie.dmn.core.util.MsgUtil;
import org.kie.dmn.model.api.DMNElementReference;
import org.kie.dmn.core.impl.DMNMessageImpl;
import org.kie.dmn.api.core.DMNMessage;
import org.kie.dmn.feel.parser.feel11.FEELParser;
import org.kie.dmn.feel.lang.types.BuiltInType;
import org.kie.dmn.core.compiler.DMNCompilerImpl;
import org.kie.dmn.core.compiler.ImportDMNResolverUtil;
import org.kie.dmn.validation.ValidatorUtil;
import org.kie.dmn.model.api.*;
import org.kie.dmn.model.api.DMNElement;
import org.kie.dmn.api.feel.runtime.events.FEELEvent;
import org.kie.dmn.core.util.Msg;
import org.kie.dmn.feel.runtime.events.SyntaxErrorEvent;
import static org.kie.dmn.validation.ValidatorUtil.getRootItemDef;
import static org.kie.dmn.validation.ValidatorUtil.rightOfHash;
import static org.kie.dmn.validation.ValidatorUtil.nameOrIDOfTable;
import static org.kie.dmn.validation.ValidatorUtil.leftOfHash;
import static org.kie.dmn.validation.DMNv1x.Rules91573BCE7659DE46F3EF9933A8394CC6.*;
import static org.kie.dmn.validation.DMNv1x.Rules91573BCE7659DE46F3EF9933A8394CC6.*;

public class Rules91573BCE7659DE46F3EF9933A8394CC6RuleMethods10 {

    /**
     * Rule name: RELATION_ROW_CELLCOUNTMISMATCH
     */
    public static org.drools.model.Rule rule_RELATION__ROW__CELLCOUNTMISMATCH() {
        final org.drools.model.Variable<org.kie.dmn.model.api.Relation> var_$rel = D.declarationOf(org.kie.dmn.model.api.Relation.class,
                                                                                                   DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_Relation_Metadata_INSTANCE,
                                                                                                   "$rel");
        final org.drools.model.Variable<org.kie.dmn.model.api.List> var_$row = D.declarationOf(org.kie.dmn.model.api.List.class,
                                                                                               DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_List_Metadata_INSTANCE,
                                                                                               "$row",
                                                                                               D.from(var_$rel,
                                                                                                      org.kie.dmn.validation.DMNv1x.PF7.LambdaExtractorF74B3DE518AE3D6C59208D746D34C664.INSTANCE));
        org.drools.model.Rule rule = D.rule("org.kie.dmn.validation.DMNv1x",
                                            "RELATION_ROW_CELLCOUNTMISMATCH")
                                      .build(D.pattern(var_$rel).watch("column"),
                                             D.pattern(var_$row).expr("GENERATED_27E3A79898EEB5BA9B5BDDEFC44C1A5E",
                                                                      var_$rel,
                                                                      org.kie.dmn.validation.DMNv1x.P60.LambdaPredicate608380E3CAD22EC24CC747A2DFF82791.INSTANCE,
                                                                      D.reactOn("expression")),
                                             D.on(var_$row,
                                                  var_$rel,
                                                  var_reporter).execute(org.kie.dmn.validation.DMNv1x.P87.LambdaConsequence87974EC03401C625B11333CB69EDC4A8.INSTANCE));
        return rule;
    }

    /**
     * Rule name: ORG_UNIT_DECISION_MADE_WRONG_TYPE
     */
    public static org.drools.model.Rule rule_ORG__UNIT__DECISION__MADE__WRONG__TYPE() {
        final org.drools.model.Variable<org.kie.dmn.model.api.OrganizationUnit> var_$d = D.declarationOf(org.kie.dmn.model.api.OrganizationUnit.class,
                                                                                                         DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_OrganizationUnit_Metadata_INSTANCE,
                                                                                                         "$d");
        final org.drools.model.Variable<org.kie.dmn.model.api.DMNElementReference> var_$elemRef = D.declarationOf(org.kie.dmn.model.api.DMNElementReference.class,
                                                                                                                  DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_DMNElementReference_Metadata_INSTANCE,
                                                                                                                  "$elemRef",
                                                                                                                  D.reactiveFrom(var_$d,
                                                                                                                                 org.kie.dmn.validation.DMNv1x.PDB.LambdaExtractorDBE797FEBD224FC41C9F081A70AFBF2D.INSTANCE));
        final org.drools.model.Variable<org.kie.dmn.model.api.DMNElement> var_$element = D.declarationOf(org.kie.dmn.model.api.DMNElement.class,
                                                                                                         DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_DMNElement_Metadata_INSTANCE,
                                                                                                         "$element");
        org.drools.model.Rule rule = D.rule("org.kie.dmn.validation.DMNv1x",
                                            "ORG_UNIT_DECISION_MADE_WRONG_TYPE")
                                      .build(D.pattern(var_$d),
                                             D.pattern(var_$elemRef),
                                             D.pattern(var_$element).expr("GENERATED_D0E504FF35A21EB89B9DA2334A730A81",
                                                                          var_$elemRef,
                                                                          org.kie.dmn.validation.DMNv1x.PAF.LambdaPredicateAF6997447CB00D70751A95011EFCCA67.INSTANCE,
                                                                          D.reactOn("id")).expr("GENERATED_F92F0AA9BAA9C787FEC1DCD95377596F",
                                                                                                org.kie.dmn.validation.DMNv1x.P1D.LambdaPredicate1D8C90DC2C7BC4B38830106F2621D153.INSTANCE),
                                             D.on(var_$d,
                                                  var_$element,
                                                  var_reporter,
                                                  var_$elemRef).execute(org.kie.dmn.validation.DMNv1x.P10.LambdaConsequence10FED5F4173D4DD5BC801AC24CB3350E.INSTANCE));
        return rule;
    }

    /**
     * Rule name: ORG_UNIT_DECISION_OWNED_WRONG_TYPE
     */
    public static org.drools.model.Rule rule_ORG__UNIT__DECISION__OWNED__WRONG__TYPE() {
        final org.drools.model.Variable<org.kie.dmn.model.api.OrganizationUnit> var_$d = D.declarationOf(org.kie.dmn.model.api.OrganizationUnit.class,
                                                                                                         DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_OrganizationUnit_Metadata_INSTANCE,
                                                                                                         "$d");
        final org.drools.model.Variable<org.kie.dmn.model.api.DMNElementReference> var_$elemRef = D.declarationOf(org.kie.dmn.model.api.DMNElementReference.class,
                                                                                                                  DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_DMNElementReference_Metadata_INSTANCE,
                                                                                                                  "$elemRef",
                                                                                                                  D.reactiveFrom(var_$d,
                                                                                                                                 org.kie.dmn.validation.DMNv1x.PCE.LambdaExtractorCE5B5DCD3CA6042EBEC9F552DCA95D51.INSTANCE));
        final org.drools.model.Variable<org.kie.dmn.model.api.DMNElement> var_$element = D.declarationOf(org.kie.dmn.model.api.DMNElement.class,
                                                                                                         DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_DMNElement_Metadata_INSTANCE,
                                                                                                         "$element");
        org.drools.model.Rule rule = D.rule("org.kie.dmn.validation.DMNv1x",
                                            "ORG_UNIT_DECISION_OWNED_WRONG_TYPE")
                                      .build(D.pattern(var_$d),
                                             D.pattern(var_$elemRef),
                                             D.pattern(var_$element).expr("GENERATED_D0E504FF35A21EB89B9DA2334A730A81",
                                                                          var_$elemRef,
                                                                          org.kie.dmn.validation.DMNv1x.PAF.LambdaPredicateAF6997447CB00D70751A95011EFCCA67.INSTANCE,
                                                                          D.reactOn("id")).expr("GENERATED_F92F0AA9BAA9C787FEC1DCD95377596F",
                                                                                                org.kie.dmn.validation.DMNv1x.P1D.LambdaPredicate1D8C90DC2C7BC4B38830106F2621D153.INSTANCE),
                                             D.on(var_$d,
                                                  var_$element,
                                                  var_reporter,
                                                  var_$elemRef).execute(org.kie.dmn.validation.DMNv1x.P10.LambdaConsequence10FED5F4173D4DD5BC801AC24CB3350E.INSTANCE));
        return rule;
    }

    /**
     * Rule name: PERF_INDICATOR_IMP_DECISION_WRONG_TYPE
     */
    public static org.drools.model.Rule rule_PERF__INDICATOR__IMP__DECISION__WRONG__TYPE() {
        final org.drools.model.Variable<org.kie.dmn.model.api.PerformanceIndicator> var_$d = D.declarationOf(org.kie.dmn.model.api.PerformanceIndicator.class,
                                                                                                             DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_PerformanceIndicator_Metadata_INSTANCE,
                                                                                                             "$d");
        final org.drools.model.Variable<org.kie.dmn.model.api.DMNElementReference> var_$elemRef = D.declarationOf(org.kie.dmn.model.api.DMNElementReference.class,
                                                                                                                  DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_DMNElementReference_Metadata_INSTANCE,
                                                                                                                  "$elemRef",
                                                                                                                  D.reactiveFrom(var_$d,
                                                                                                                                 org.kie.dmn.validation.DMNv1x.PD6.LambdaExtractorD64DA69093DCC29CF6B9F4C162745CC8.INSTANCE));
        final org.drools.model.Variable<org.kie.dmn.model.api.DMNElement> var_$element = D.declarationOf(org.kie.dmn.model.api.DMNElement.class,
                                                                                                         DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_DMNElement_Metadata_INSTANCE,
                                                                                                         "$element");
        org.drools.model.Rule rule = D.rule("org.kie.dmn.validation.DMNv1x",
                                            "PERF_INDICATOR_IMP_DECISION_WRONG_TYPE")
                                      .build(D.pattern(var_$d),
                                             D.pattern(var_$elemRef),
                                             D.pattern(var_$element).expr("GENERATED_D0E504FF35A21EB89B9DA2334A730A81",
                                                                          var_$elemRef,
                                                                          org.kie.dmn.validation.DMNv1x.PAF.LambdaPredicateAF6997447CB00D70751A95011EFCCA67.INSTANCE,
                                                                          D.reactOn("id")).expr("GENERATED_F92F0AA9BAA9C787FEC1DCD95377596F",
                                                                                                org.kie.dmn.validation.DMNv1x.P1D.LambdaPredicate1D8C90DC2C7BC4B38830106F2621D153.INSTANCE),
                                             D.on(var_$d,
                                                  var_$element,
                                                  var_reporter,
                                                  var_$elemRef).execute(org.kie.dmn.validation.DMNv1x.P1E.LambdaConsequence1E00F518C9D8A94066D355C9755CA159.INSTANCE));
        return rule;
    }

    /**
     * Rule name: ELEMREF_NOHASH_p1
     */
    public static org.drools.model.Rule rule_ELEMREF__NOHASH__p1() {
        final org.drools.model.Variable<org.kie.dmn.model.api.Import> var_GENERATED_$pattern_Import$61$ = D.declarationOf(org.kie.dmn.model.api.Import.class,
                                                                                                                          DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_Import_Metadata_INSTANCE,
                                                                                                                          "GENERATED_$pattern_Import$61$");
        final org.drools.model.Variable<org.kie.dmn.model.api.DMNElementReference> var_$oc = D.declarationOf(org.kie.dmn.model.api.DMNElementReference.class,
                                                                                                             DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_DMNElementReference_Metadata_INSTANCE,
                                                                                                             "$oc");
        org.drools.model.Rule rule = D.rule("org.kie.dmn.validation.DMNv1x",
                                            "ELEMREF_NOHASH_p1")
                                      .build(D.not(D.pattern(var_GENERATED_$pattern_Import$61$)),
                                             D.pattern(var_$oc).expr("GENERATED_85086920CAFE922F17B38B6717C879F6",
                                                                     org.kie.dmn.validation.DMNv1x.P59.LambdaPredicate59091A387A39A76FF640CF525ABF724C.INSTANCE,
                                                                     D.reactOn("href")).expr("GENERATED_CCD95C0CBE2FE5CF935563A8046E3192",
                                                                                             org.kie.dmn.validation.DMNv1x.PE1.LambdaPredicateE186D310533DF7B996420C8355F1D383.INSTANCE,
                                                                                             D.reactOn("href")),
                                             D.on(var_$oc,
                                                  var_reporter).execute(org.kie.dmn.validation.DMNv1x.PDB.LambdaConsequenceDBC622A8B6032233E0A773E941792C9A.INSTANCE));
        return rule;
    }
}

==> kie-dmn-validation-999-20250404.023211-233-sources.jar: org/kie/dmn/validation/DMNv1x/Rules91573BCE7659DE46F3EF9933A8394CC6RuleMethods10.java <==
package org.kie.dmn.validation.DMNv1x;

import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;
import org.kie.dmn.core.util.MsgUtil;
import org.kie.dmn.model.api.DMNElementReference;
import org.kie.dmn.core.impl.DMNMessageImpl;
import org.kie.dmn.api.core.DMNMessage;
import org.kie.dmn.feel.parser.feel11.FEELParser;
import org.kie.dmn.feel.lang.types.BuiltInType;
import org.kie.dmn.core.compiler.DMNCompilerImpl;
import org.kie.dmn.core.compiler.DMNImportsUtil;
import org.kie.dmn.validation.ValidatorUtil;
import org.kie.dmn.model.api.*;
import org.kie.dmn.model.api.DMNElement;
import org.kie.dmn.api.feel.runtime.events.FEELEvent;
import org.kie.dmn.core.util.Msg;
import org.kie.dmn.feel.runtime.events.SyntaxErrorEvent;
import static org.kie.dmn.validation.ValidatorUtil.getRootItemDef;
import static org.kie.dmn.validation.ValidatorUtil.rightOfHash;
import static org.kie.dmn.validation.ValidatorUtil.nameOrIDOfTable;
import static org.kie.dmn.validation.ValidatorUtil.leftOfHash;
import static org.kie.dmn.validation.DMNv1x.Rules91573BCE7659DE46F3EF9933A8394CC6.*;
import static org.kie.dmn.validation.DMNv1x.Rules91573BCE7659DE46F3EF9933A8394CC6.*;

public class Rules91573BCE7659DE46F3EF9933A8394CC6RuleMethods10 {

    /**
     * Rule name: RELATION_ROW_CELLCOUNTMISMATCH
     */
    public static org.drools.model.Rule rule_RELATION__ROW__CELLCOUNTMISMATCH() {
        final org.drools.model.Variable<org.kie.dmn.model.api.Relation> var_$rel = D.declarationOf(org.kie.dmn.model.api.Relation.class,
                                                                                                   DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_Relation_Metadata_INSTANCE,
                                                                                                   "$rel");
        final org.drools.model.Variable<org.kie.dmn.model.api.List> var_$row = D.declarationOf(org.kie.dmn.model.api.List.class,
                                                                                               DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_List_Metadata_INSTANCE,
                                                                                               "$row",
                                                                                               D.from(var_$rel,
                                                                                                      org.kie.dmn.validation.DMNv1x.P25.LambdaExtractor258597E7FA201F0D6367B752B150B13C.INSTANCE));
        org.drools.model.Rule rule = D.rule("org.kie.dmn.validation.DMNv1x",
                                            "RELATION_ROW_CELLCOUNTMISMATCH")
                                      .build(D.pattern(var_$rel).watch("column"),
                                             D.pattern(var_$row).expr("GENERATED_27E3A79898EEB5BA9B5BDDEFC44C1A5E",
                                                                      var_$rel,
                                                                      org.kie.dmn.validation.DMNv1x.P04.LambdaPredicate04CF57F72EB6210FBA295044B63D540B.INSTANCE,
                                                                      D.reactOn("expression")),
                                             D.on(var_$row,
                                                  var_$rel,
                                                  var_reporter).execute(org.kie.dmn.validation.DMNv1x.PF6.LambdaConsequenceF6985BD29539B2F93ADD281DF2DBB690.INSTANCE));
        return rule;
    }

    /**
     * Rule name: ORG_UNIT_DECISION_MADE_WRONG_TYPE
     */
    public static org.drools.model.Rule rule_ORG__UNIT__DECISION__MADE__WRONG__TYPE() {
        final org.drools.model.Variable<org.kie.dmn.model.api.OrganizationUnit> var_$d = D.declarationOf(org.kie.dmn.model.api.OrganizationUnit.class,
                                                                                                         DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_OrganizationUnit_Metadata_INSTANCE,
                                                                                                         "$d");
        final org.drools.model.Variable<org.kie.dmn.model.api.DMNElementReference> var_$elemRef = D.declarationOf(org.kie.dmn.model.api.DMNElementReference.class,
                                                                                                                  DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_DMNElementReference_Metadata_INSTANCE,
                                                                                                                  "$elemRef",
                                                                                                                  D.reactiveFrom(var_$d,
                                                                                                                                 org.kie.dmn.validation.DMNv1x.PD7.LambdaExtractorD77B34E2F0308C99489F54983D5AAFD7.INSTANCE));
        final org.drools.model.Variable<org.kie.dmn.model.api.DMNElement> var_$element = D.declarationOf(org.kie.dmn.model.api.DMNElement.class,
                                                                                                         DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_DMNElement_Metadata_INSTANCE,
                                                                                                         "$element");
        org.drools.model.Rule rule = D.rule("org.kie.dmn.validation.DMNv1x",
                                            "ORG_UNIT_DECISION_MADE_WRONG_TYPE")
                                      .build(D.pattern(var_$d),
                                             D.pattern(var_$elemRef),
                                             D.pattern(var_$element).expr("GENERATED_D0E504FF35A21EB89B9DA2334A730A81",
                                                                          var_$elemRef,
                                                                          org.kie.dmn.validation.DMNv1x.P86.LambdaPredicate86ECDA1712D0E35508A9515F967A9D3D.INSTANCE,
                                                                          D.reactOn("id")).expr("GENERATED_F92F0AA9BAA9C787FEC1DCD95377596F",
                                                                                                org.kie.dmn.validation.DMNv1x.P91.LambdaPredicate91BB03994CCC9299E3BCCEC35B76A532.INSTANCE),
                                             D.on(var_$d,
                                                  var_$element,
                                                  var_reporter,
                                                  var_$elemRef).execute(org.kie.dmn.validation.DMNv1x.P5F.LambdaConsequence5F592524ECA9D3A7DAAED7AD8D4F8108.INSTANCE));
        return rule;
    }

    /**
     * Rule name: ORG_UNIT_DECISION_OWNED_WRONG_TYPE
     */
    public static org.drools.model.Rule rule_ORG__UNIT__DECISION__OWNED__WRONG__TYPE() {
        final org.drools.model.Variable<org.kie.dmn.model.api.OrganizationUnit> var_$d = D.declarationOf(org.kie.dmn.model.api.OrganizationUnit.class,
                                                                                                         DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_OrganizationUnit_Metadata_INSTANCE,
                                                                                                         "$d");
        final org.drools.model.Variable<org.kie.dmn.model.api.DMNElementReference> var_$elemRef = D.declarationOf(org.kie.dmn.model.api.DMNElementReference.class,
                                                                                                                  DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_DMNElementReference_Metadata_INSTANCE,
                                                                                                                  "$elemRef",
                                                                                                                  D.reactiveFrom(var_$d,
                                                                                                                                 org.kie.dmn.validation.DMNv1x.PB7.LambdaExtractorB75205864B47EE364CE17B48D98B7A03.INSTANCE));
        final org.drools.model.Variable<org.kie.dmn.model.api.DMNElement> var_$element = D.declarationOf(org.kie.dmn.model.api.DMNElement.class,
                                                                                                         DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_DMNElement_Metadata_INSTANCE,
                                                                                                         "$element");
        org.drools.model.Rule rule = D.rule("org.kie.dmn.validation.DMNv1x",
                                            "ORG_UNIT_DECISION_OWNED_WRONG_TYPE")
                                      .build(D.pattern(var_$d),
                                             D.pattern(var_$elemRef),
                                             D.pattern(var_$element).expr("GENERATED_D0E504FF35A21EB89B9DA2334A730A81",
                                                                          var_$elemRef,
                                                                          org.kie.dmn.validation.DMNv1x.P86.LambdaPredicate86ECDA1712D0E35508A9515F967A9D3D.INSTANCE,
                                                                          D.reactOn("id")).expr("GENERATED_F92F0AA9BAA9C787FEC1DCD95377596F",
                                                                                                org.kie.dmn.validation.DMNv1x.P91.LambdaPredicate91BB03994CCC9299E3BCCEC35B76A532.INSTANCE),
                                             D.on(var_$d,
                                                  var_$element,
                                                  var_reporter,
                                                  var_$elemRef).execute(org.kie.dmn.validation.DMNv1x.P5F.LambdaConsequence5F592524ECA9D3A7DAAED7AD8D4F8108.INSTANCE));
        return rule;
    }

    /**
     * Rule name: PERF_INDICATOR_IMP_DECISION_WRONG_TYPE
     */
    public static org.drools.model.Rule rule_PERF__INDICATOR__IMP__DECISION__WRONG__TYPE() {
        final org.drools.model.Variable<org.kie.dmn.model.api.PerformanceIndicator> var_$d = D.declarationOf(org.kie.dmn.model.api.PerformanceIndicator.class,
                                                                                                             DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_PerformanceIndicator_Metadata_INSTANCE,
                                                                                                             "$d");
        final org.drools.model.Variable<org.kie.dmn.model.api.DMNElementReference> var_$elemRef = D.declarationOf(org.kie.dmn.model.api.DMNElementReference.class,
                                                                                                                  DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_DMNElementReference_Metadata_INSTANCE,
                                                                                                                  "$elemRef",
                                                                                                                  D.reactiveFrom(var_$d,
                                                                                                                                 org.kie.dmn.validation.DMNv1x.PF8.LambdaExtractorF82D9F06F3573C846F538430AB777085.INSTANCE));
        final org.drools.model.Variable<org.kie.dmn.model.api.DMNElement> var_$element = D.declarationOf(org.kie.dmn.model.api.DMNElement.class,
                                                                                                         DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_DMNElement_Metadata_INSTANCE,
                                                                                                         "$element");
        org.drools.model.Rule rule = D.rule("org.kie.dmn.validation.DMNv1x",
                                            "PERF_INDICATOR_IMP_DECISION_WRONG_TYPE")
                                      .build(D.pattern(var_$d),
                                             D.pattern(var_$elemRef),
                                             D.pattern(var_$element).expr("GENERATED_D0E504FF35A21EB89B9DA2334A730A81",
                                                                          var_$elemRef,
                                                                          org.kie.dmn.validation.DMNv1x.P86.LambdaPredicate86ECDA1712D0E35508A9515F967A9D3D.INSTANCE,
                                                                          D.reactOn("id")).expr("GENERATED_F92F0AA9BAA9C787FEC1DCD95377596F",
                                                                                                org.kie.dmn.validation.DMNv1x.P91.LambdaPredicate91BB03994CCC9299E3BCCEC35B76A532.INSTANCE),
                                             D.on(var_$d,
                                                  var_$element,
                                                  var_reporter,
                                                  var_$elemRef).execute(org.kie.dmn.validation.DMNv1x.P2F.LambdaConsequence2F1E15E5511AAA967FE379B3EECD8D6E.INSTANCE));
        return rule;
    }

    /**
     * Rule name: ELEMREF_NOHASH_p1
     */
    public static org.drools.model.Rule rule_ELEMREF__NOHASH__p1() {
        final org.drools.model.Variable<org.kie.dmn.model.api.Import> var_GENERATED_$pattern_Import$109$ = D.declarationOf(org.kie.dmn.model.api.Import.class,
                                                                                                                           DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_Import_Metadata_INSTANCE,
                                                                                                                           "GENERATED_$pattern_Import$109$");
        final org.drools.model.Variable<org.kie.dmn.model.api.DMNElementReference> var_$oc = D.declarationOf(org.kie.dmn.model.api.DMNElementReference.class,
                                                                                                             DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_DMNElementReference_Metadata_INSTANCE,
                                                                                                             "$oc");
        org.drools.model.Rule rule = D.rule("org.kie.dmn.validation.DMNv1x",
                                            "ELEMREF_NOHASH_p1")
                                      .build(D.not(D.pattern(var_GENERATED_$pattern_Import$109$)),
                                             D.pattern(var_$oc).expr("GENERATED_85086920CAFE922F17B38B6717C879F6",
                                                                     org.kie.dmn.validation.DMNv1x.PA9.LambdaPredicateA9DCD2D1D8B7242821208AB217353C7A.INSTANCE,
                                                                     D.reactOn("href")).expr("GENERATED_CCD95C0CBE2FE5CF935563A8046E3192",
                                                                                             org.kie.dmn.validation.DMNv1x.P43.LambdaPredicate43E4ED8DCB3CCF4D65C41BA5CE5ABDD7.INSTANCE,
                                                                                             D.reactOn("href")),
                                             D.on(var_$oc,
                                                  var_reporter).execute(org.kie.dmn.validation.DMNv1x.P3F.LambdaConsequence3FB567BC6AE11F5431E7E4FFB0F63A6C.INSTANCE));
        return rule;
    }
}
